Enum GeometryNode

#[non_exhaustive]
pub enum GeometryNode {
Show 27 variants Point2(Point2), Point3(Point3), Vector2(Vec2), Vector3(Vec3), Frame2(Frame2), Frame3(Frame3), Transform(Transform3), PointList2(Vec<Point2>), PointList3(Vec<Point3>), Curve2(Curve2), Curve3(Curve3), CurveRelation(CurveRelation), PointOnCurve(PointOnCurve), Surface(Surface), SurfaceRelation(SurfaceRelation), PointOnSurface(PointOnSurface), Profile(Profile), OpenProfile(OpenProfile), Primitive(Primitive), HalfSpace(HalfSpace), SolidOperation(SolidOperation), BRep(BRep<NodeId>), PolygonMesh(PolygonMesh), TriMesh(TriMesh), BoundingBox(Aabb), Instance(Instance), Collection(Vec<NodeId>),
}
One node in an immutable geometry DAG.

The enum is non-exhaustive so representation growth is semver-compatible. Compilers must turn unknown/unsupported families into a structured Unsupported result rather than a wildcard no-op.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Point2(Point2)

Two-dimensional position.



Point3(Point3)

Three-dimensional position.



Vector2(Vec2)

Two-dimensional direction/vector.



Vector3(Vec3)

Three-dimensional direction/vector.



Frame2(Frame2)

Two-dimensional axis placement.



Frame3(Frame3)

Three-dimensional axis placement.



Transform(Transform3)

Composed affine transform.



PointList2(Vec<Point2>)

Dense two-dimensional point list.



PointList3(Vec<Point3>)

Dense three-dimensional point list.



Curve2(Curve2)

Atomic two-dimensional curve.



Curve3(Curve3)

Atomic three-dimensional curve.



CurveRelation(CurveRelation)

Curve composition/constraint.



PointOnCurve(PointOnCurve)

Point on a curve.



Surface(Surface)

Atomic surface.



SurfaceRelation(SurfaceRelation)

Surface composition/constraint.



PointOnSurface(PointOnSurface)

Point on a surface.



Profile(Profile)

Exact section profile with area semantics.



OpenProfile(OpenProfile)

Authored exact open profile path without area or width semantics.



Primitive(Primitive)

Exact primitive solid.



HalfSpace(HalfSpace)

Unbounded half-space.



SolidOperation(SolidOperation)

Solid construction instruction.



BRep(BRep<NodeId>)

Exact topological representation linked to graph curve/surface nodes.



PolygonMesh(PolygonMesh)

Polygonal n-gon mesh before triangulation.



TriMesh(TriMesh)

Triangle mesh.



BoundingBox(Aabb)

Axis-aligned bounds.



Instance(Instance)

Instanced/mapped geometry.



Collection(Vec<NodeId>)

Ordered geometric set or representation.

Implementations

Source

impl GeometryNode

pub fn references(&self) -> Vec<NodeId>

Direct graph dependencies in deterministic order.