BuiltInNode

Trait BuiltInNode 

pub trait BuiltInNode: Sealed + Into<GeometryNode> { }
A built-in neutral value that can be inserted into a crate::GeometryGraph.

This is sealed deliberately. Third-party kernels extend execution through the open traits in operation-contract packages; source adapters extend input by translating their values into one of the canonical node families.

ⓘ
use axiolid_model::{BuiltInNode, GeometryNode};

struct ForeignNode;

impl Into<GeometryNode> for ForeignNode {
    fn into(self) -> GeometryNode {
        panic!("compile-only example")
    }
}

// Rejected because the private sealing trait cannot be implemented here.
impl BuiltInNode for ForeignNode {}

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl BuiltInNode for Aabb

Source

impl BuiltInNode for BRep<NodeId>

Source

impl BuiltInNode for Curve2

Source

impl BuiltInNode for Curve3

Source

impl BuiltInNode for Frame2

Source

impl BuiltInNode for Frame3

Source

impl BuiltInNode for HalfSpace

Source

impl BuiltInNode for PolygonMesh

Source

impl BuiltInNode for Primitive

Source

impl BuiltInNode for Profile

Source

impl BuiltInNode for Surface

Source

impl BuiltInNode for Transform3

Source

impl BuiltInNode for TriMesh

Implementors